@@ -34,7 +34,7 @@
 #'
 #' @return An object of class \code{tvlm}
 #' The object of class \code{tvlm} have the following components:
-#' \item{tvcoef}{A matrix of dimensions}
+#' \item{coefficients}{A matrix of dimensions}
 #' \item{fitted}{The fitted values.}
 #' \item{residuals}{Estimation residuals.}
 #' \item{x}{A matrix with the regressors data.}
@@ -47,7 +47,7 @@
 #' \item{level}{Confidence interval range.}
 #' \item{runs}{Number of bootstrap replications.}
 #' \item{tboot}{Type of bootstrap.}
-#' \item{BOOT}{List with all bootstrap replications of \code{tvcoef}, if done.}
+#' \item{BOOT}{List with all bootstrap replications of \code{coefficients}, if done.}
 #' 
 #' @seealso \code{\link{bw}}, \code{\link{tvAR}}, \code{\link{confint}}, 
 #' \code{\link{plot}}, \code{\link{print}} and \code{\link{summary}}
@@ -73,10 +73,10 @@
 #' ##Bollerslev t al. (2016) HARQ model
 #' HARQ <- with(RV2, lm(RV ~ RV_lag + I(RV_lag * RQ_lag_sqrt) + RV_week + RV_month))
 #' 
-#' #Casas et al. (2018) TV-HARQ model
+#' #Casas et al. (2018) TVHARQ model
 #' tvHARQ <- with(RV2, tvLM (RV ~ RV_lag + RV_week + RV_month, z = RQ_lag_sqrt, 
 #'                          bw = 0.0061))
-#' boxplot(data.frame(tvHARQ = tvHARQ$tvcoef[,2] * RV2$RV_lag,
+#' boxplot(data.frame(tvHARQ = tvHARQ$coefficients[,2] * RV2$RV_lag,
 #'                    HARQ = (HARQ$coef[2] + HARQ$coef[3] * RV2$RQ_lag_sqrt)*RV2$RV_lag),
 #'                    main = expression (RV[t-1]), outline = FALSE)
 #'                  
@@ -124,13 +124,13 @@ tvLM<-function (formula, z = NULL, ez = NULL, data, bw = NULL, cv.block = 0, est
   xnames<-colnames(x)
   if(is.null(xnames))
     xnames <- paste("X", 1:nvar, collate="&", sep="")
-  tvcoef <-results$tvcoef
-  colnames(tvcoef) <- xnames
-  result <- list(tvcoef = tvcoef, Lower = NULL, Upper = NULL, fitted = results$fitted,
+  coefficients <-results$coefficients
+  colnames(coefficients) <- xnames
+  result <- list(coefficients = coefficients, Lower = NULL, Upper = NULL, fitted = results$fitted,
                  residuals = results$resid, x = x, y = y, z = z, ez = ez, bw = bw, 
                  cv.block = cv.block, obs = length(y), est = est, tkernel = tkernel,
                  singular.ok = singular.ok, level = 0, runs = 0, 
-                 tboot = NULL, BOOT = NULL)
+                 tboot = NULL, BOOT = NULL, call = match.call())
   class(result) <- "tvlm"
   return(result)
 }
