@@ -1,9 +1,9 @@
-## ----setup, include = FALSE----------------------------------------------
+## ----setup, include = FALSE---------------------------------------------------
 knitr::opts_chunk$set(echo = TRUE, tidy = TRUE, fig.width = 6,
                       fig.height = 4, fig.align = "center")
 library(tvReg)
 
-## ----tvLM----------------------------------------------------------------
+## ----tvLM---------------------------------------------------------------------
  ##Simulate a linear process with time-varying coefficient
  ##as functions of rescaled time period.
  library(tvReg)
@@ -22,13 +22,13 @@ library(tvReg)
  ##Plot the estimates of beta1
  par (mar = c(4,4,1,1), oma = c(1,1,1,1))
  plot(tau,beta[, 1], type = "l", main = "", ylab = expression(beta[1]),
- xlab = expression(tau), ylim = range(beta[,1], model.tvLM$tvcoef[, 1]))
+ xlab = expression(tau), ylim = range(beta[,1], model.tvLM$coefficients[, 1]))
  abline(h = coef.lm[1], col = 2)
- lines(tau, model.tvLM$tvcoef[, 1], col=4)
+ lines(tau, model.tvLM$coefficients[, 1], col=4)
  legend("topright", c(expression(beta[1]), "lm", "tvlm"), col = c(1, 2, 4), 
         bty = "n", lty = 1, cex = 0.8)
 
-## ----CI, eval = TRUE-----------------------------------------------------
+## ----CI, eval = TRUE----------------------------------------------------------
 
 ##Obtain the 90% confidence interval of the coefficients for an object of the class attribute tvlm
 model.tvLM.90 <- confint (model.tvLM, level = 0.90, runs = 50)
@@ -36,11 +36,11 @@ model.tvLM.90 <- confint (model.tvLM, level = 0.90, runs = 50)
 ##Obtain the 95% confidence interval of the same object. This will reused the resamples of object model.tvLM.90. So the second confidence interval calculation is faster
 model.tvLM.95 <- confint(model.tvLM.90)
 
-## ----PLOT,  eval = TRUE--------------------------------------------------
+## ----PLOT,  eval = TRUE-------------------------------------------------------
 ##Plot coefficient estimates and confidence intervals (if calculated) of objects of the class attribute tvlm
 plot(model.tvLM.90)
 
-## ----tvLM2---------------------------------------------------------------
+## ----tvLM2--------------------------------------------------------------------
  ##Data generation
  set.seed (42)
  z <- stats::arima.sim (n = 1000, list(ar = c(0.8897, -0.4858), ma = c(-0.2279, 0.2488)), sd = sqrt(0.1796))
@@ -59,11 +59,11 @@ plot(model.tvLM.90)
  ylab = expression(beta[1]), xlab = expression(z[t]),
  ylim = range(beta[,1], coefficients(model.tvLM2)[, 1]))
  abline(h = coef.lm[1], col = 2)
- lines(z[sort.index], model.tvLM2$tvcoef[sort.index, 1], col = 4)
+ lines(z[sort.index], model.tvLM2$coefficients[sort.index, 1], col = 4)
  legend("top", c(expression(beta[1]), "lm", "tvLM"), col = c(1, 2, 4), bty = "n", 
         lty = 1, cex = 0.5)
 
-## ----tvAR----------------------------------------------------------------
+## ----tvAR---------------------------------------------------------------------
  ##Simulate an tvAR(2) process
  tt<-(1:1000)/1000
  beta <- cbind( 0.5 * cos (2 * pi * tt), (tt - 0.5)^2)
@@ -81,7 +81,7 @@ plot(model.tvLM.90)
  model.ar.2p <- ar.ols(Y, aic = FALSE, order = 2, intercept = FALSE, demean = FALSE)
  model.tvAR.2p <- tvAR(Y, p = 2, type = "none", est = "ll")
 
-## ----tvAR.z--------------------------------------------------------------
+## ----tvAR.z-------------------------------------------------------------------
 ##Simulate a AR(1) process with coefficients depending on z
 z <- runif(2000, -1, 1)
 beta <- (z - 0.5)^2
@@ -109,18 +109,18 @@ model.tvAR.80 <- confint(model.tvAR.1p.z, tboot = "wild2", level = 0.8, runs = 5
 plot(model.tvAR.80)
 
 
-## ----PRINT, eval = TRUE--------------------------------------------------
+## ----PRINT, eval = TRUE-------------------------------------------------------
 ##Summary of model.tvAR.80
 summary(model.tvAR.80)
 
 ##Print of model.tvAR.80
 print(model.tvAR.80)
 
-## ----tvAR2, eval = FALSE-------------------------------------------------
+## ----tvAR2, eval = FALSE------------------------------------------------------
 #   ##Estimate only coefficient from odd lags and the intercept
 #   tvAR.6p <- tvAR(y, p = 6, type = "const", fixed = c(NA, NA, 0, NA, 0, NA, 0), est = "ll")
 
-## ----tvOLS---------------------------------------------------------------
+## ----tvOLS--------------------------------------------------------------------
 data("Kmenta", package = "systemfit")
 eqDemand <- consump ~ price + income
 eqSupply <- consump ~ price + farmPrice + trend
@@ -141,14 +141,14 @@ plot(model.tvOLS)
 ##Print of model model.tvOLS 
 print(model.tvOLS)
 
-## ----tvFGLS--------------------------------------------------------------
+## ----tvFGLS-------------------------------------------------------------------
 ##FGLS estimation - SURE estimation
 fgls1.fit <- systemfit::systemfit(system, data = Kmenta, method = "SUR")
 
 ##tvFGLS estimation - tvSURE estimation
 tvfgls1.fit <- tvSURE(system, data = Kmenta, method = "tvFGLS")
 
-## ----tvFGLS2-------------------------------------------------------------
+## ----tvFGLS2------------------------------------------------------------------
 ##Iterative FGLS estimation - SUR estimation
 fgls2.fit <- systemfit::systemfit(system, data = Kmenta, method = "SUR", maxit = 100)
 
@@ -156,7 +156,7 @@ fgls2.fit <- systemfit::systemfit(system, data = Kmenta, method = "SUR", maxit =
 tvfgls2.fit <- tvSURE(system, data = Kmenta, method = "tvFGLS",
 control = list(tol = 0.001, maxiter = 100))
 
-## ----tvFGLS.rest,  eval = FALSE------------------------------------------
+## ----tvFGLS.rest,  eval = FALSE-----------------------------------------------
 #  ##Estimation with 2 restrictions
 #  Rrestr <- matrix(0, 2, 7)
 #  Rrestr[1, 7] <- 1
@@ -166,7 +166,29 @@ control = list(tol = 0.001, maxiter = 100))
 #  tvfgls.rest <- tvSURE(system, data = Kmenta, method = "tvFGLS",
 #  R = Rrestr, r = qrestr, bw = tvfgls1.fit$bw, bw.cov = tvfgls1.fit$bw.cov)
 
-## ----tvVAR---------------------------------------------------------------
+## ----tvPLM,  eval = TRUE------------------------------------------------------
+data("OECD")
+print(names(OECD))
+elast.fe <- plm::plm(lhe ~ lgdp + pop65 + pop14 + public, data = OECD, 
+                     index = c("country", "year"), model = "within")
+elast.tvfe <- tvPLM (lhe ~ lgdp + pop65 + pop14 + public, data = OECD, 
+                     index = c("country", "year"), method = "within", bw = 0.8)
+elast.fe <- confint(elast.fe)
+elast.tvfe <- confint(elast.tvfe)
+plot(elast.tvfe, vars = 1, ylim = c(0.45, 1.3))
+graphics::par(mfrow = c(1, 1), 
+                mar = c(4, 4, 2, 1), oma = c(0, 0, 0, 0))
+x.axis <- 1:elast.tvfe$obs
+par(new = TRUE)
+plot(x.axis, rep(mean(elast.fe[1,]), elast.tvfe$obs), ylim = c(0.45, 1.3),
+     ylab ="", xlab ="", type = "l")
+graphics::polygon(c(rev(x.axis), x.axis), 
+                  c(rep(rev(elast.fe[1, 2]), elast.tvfe$obs),
+                    rep(elast.fe[1, 1], elast.tvfe$obs)),
+                  col = "grey10", border = NA, fillOddEven = TRUE)
+lines(x.axis, rep(mean(elast.fe[1,]), elast.tvfe$obs), col ="white")
+
+## ----tvVAR--------------------------------------------------------------------
 ##Inflation rate, unemployment rate and treasury bill interest rate for the US,
 ##as used by Primiceri (2005).
 data(usmacro, package = "bvarsv")
@@ -177,7 +199,7 @@ model.tvVAR <- tvVAR(usmacro, p = 4, type = "const")
 plot(model.tvVAR)
  
 
-## ----tvIRF---------------------------------------------------------------
+## ----tvIRF--------------------------------------------------------------------
 ##Estimate a the impulse response functions with irf and tvIRF from 
 ##previous vector autoregressive models
 model.irf <- vars::irf(model.VAR)
@@ -186,7 +208,7 @@ model.tvIRF <- tvIRF(model.tvVAR)
 ##95% confidence interval using Mammen's wild bootstrap for object of the class attribute tvirf
 model.tvIRF <- confint(model.tvIRF, runs = 30)
 
-## ----tvIRF2--------------------------------------------------------------
+## ----tvIRF2-------------------------------------------------------------------
 ##Plot the mean all tvIRF over time
 plot(model.tvIRF)
 
@@ -194,7 +216,7 @@ plot(model.tvIRF)
 ##at time 100
 plot(model.tvIRF, obs.index = 100, impulse = "tbi", response = "inf")
 
-## ----tvIRF3--------------------------------------------------------------
+## ----tvIRF3-------------------------------------------------------------------
 ##Estimate a the tvIRF with time-varying covariance function
 model.tvIRF2 <- tvIRF(model.tvVAR, cumulative = TRUE)
 
@@ -204,7 +226,7 @@ plot <- plot(model.tvIRF2, impulse ="tbi", response = "inf")
 
 
 
-## ----Sigma---------------------------------------------------------------
+## ----Sigma--------------------------------------------------------------------
 library(MASS)
 ##Generate two independent (uncorrelated) series
 y<-cbind(rnorm(200, sd= 4), rnorm(200, sd=1))
@@ -226,7 +248,7 @@ Sigma.hat <- tvCov(y, bw = bw.cov)
 ##The first time point estimate
 print(Sigma.hat[, , 1])
 
-## ----Forecast, eval = TRUE-----------------------------------------------
+## ----Forecast, eval = TRUE----------------------------------------------------
 data(RV)
 RV2 <- head(RV, 2001)
 ##Estimate/train tvHAR model
@@ -236,7 +258,7 @@ newexogen <- cbind(RV$RV_week[2002:2004], RV$RV_month[2002:2004])
 ##3-step-ahead forecast
 forecast(tvHAR, n.ahead = 3, newexogen = newexogen)
 
-## ----Predict, eval = TRUE------------------------------------------------
+## ----Predict, eval = TRUE-----------------------------------------------------
 tvHARQ <- with(RV2, tvLM (RV ~ RV_lag + RV_week + RV_month, z = RQ_lag_sqrt, 
                 bw = 0.006))
 newx <- cbind(RV$RV_lag[2002:2004], RV$RV_week[2002:2004], RV$RV_month[2002:2004])
